/// <reference types="@types/websql" />
import { Table } from "./Table";
import { ColumnInfo } from "./ColumnInfo";
export declare class DbContext<T extends Table> {
    objClass: {
        new (): T;
    };
    private db;
    private __tableName;
    private dbName;
    private __columnsDef;
    private __referencesDef;
    private gSql;
    isTrace: boolean;
    constructor(objClass: {
        new (): T;
    });
    /**
     * 查询表的所有记录
     * */
    fromSql(sql: string, value: Array<any>): Promise<Array<T>>;
    query(param: any): Promise<Array<T>>;
    /**
     * 数据库表是否存在记录，primaryValue是记录主键值
     */
    exist(primaryValue: string): Promise<boolean>;
    /**
     * 删除记录，primaryValue是记录主键值
     */
    delete(primaryValue: string): Promise<boolean>;
    save(value: T): Promise<number>;
    /**
     * 插入记录
     * */
    insert(value: T | Array<T>): Promise<number>;
    /**
     * 修改记录
     * */
    update(value: T): Promise<number>;
    /**执行sql语句 */
    execSql(sql: string, value: Array<number | string | Date | boolean | any>): Promise<number>;
    fail(transaction: SQLTransaction, error: SQLError): boolean;
    /**
     * 初始
     * */
    init(): Promise<void>;
    /**
     * 创建表
     * */
    private createTable;
    /**
     * 转化到实体元数据
     * */
    convertToMetadata(value: T): T;
    /**从表取到的数据转换成 @column 定义的类型 */
    convertToColType(val: any, colInfo: ColumnInfo): any;
}
